SF.net SVN: phpwiki:[11084] trunk

vargenau--- via phpwiki-checkins <[email protected]> Tue, 16 Apr 2024 08:11:35 +0000
Newsgroups gmane.comp.web.wiki.phpwiki.checkins
Message-ID <[email protected]>
Revision: 11084
          http://sourceforge.net/p/phpwiki/code/11084
Author:   vargenau
Date:     2024-04-16 08:11:34 +0000 (Tue, 16 Apr 2024)
Log Message:
-----------
Upgrade PEAR to relase 1.10.15, PEAR DB to release 1.12.2

Modified Paths:
--------------
    trunk/lib/pear/DB/common.php
    trunk/lib/pear/DB/dbase.php
    trunk/lib/pear/DB/fbsql.php
    trunk/lib/pear/DB/ibase.php
    trunk/lib/pear/DB/ifx.php
    trunk/lib/pear/DB/msql.php
    trunk/lib/pear/DB/mssql.php
    trunk/lib/pear/DB/mysql.php
    trunk/lib/pear/DB/mysqli.php
    trunk/lib/pear/DB/oci8.php
    trunk/lib/pear/DB/odbc.php
    trunk/lib/pear/DB/pgsql.php
    trunk/lib/pear/DB/sqlite.php
    trunk/lib/pear/DB/sqlite3.php
    trunk/lib/pear/DB/storage.php
    trunk/lib/pear/DB/sybase.php
    trunk/lib/pear/DB.php
    trunk/lib/pear/PEAR.php
    trunk/locale/it/pgsrc/NoteDiRilascio
    trunk/pgsrc/ReleaseNotes

Modified: trunk/lib/pear/DB/common.php
===================================================================
--- trunk/lib/pear/DB/common.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/common.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -20,7 +20,6 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -42,7 +41,7 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  */
 class DB_common extends PEAR

Modified: trunk/lib/pear/DB/dbase.php
===================================================================
--- trunk/lib/pear/DB/dbase.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/dbase.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -20,7 +20,6 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -41,7 +40,7 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  */
 class DB_dbase extends DB_common

Modified: trunk/lib/pear/DB/fbsql.php
===================================================================
--- trunk/lib/pear/DB/fbsql.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/fbsql.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -20,7 +20,6 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -41,7 +40,7 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  * @since      Class functional since Release 1.7.0
  */

Modified: trunk/lib/pear/DB/ibase.php
===================================================================
--- trunk/lib/pear/DB/ibase.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/ibase.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -23,7 +23,6 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -49,7 +48,7 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  * @since      Class became stable in Release 1.7.0
  */

Modified: trunk/lib/pear/DB/ifx.php
===================================================================
--- trunk/lib/pear/DB/ifx.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/ifx.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -20,7 +20,6 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -48,7 +47,7 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  */
 class DB_ifx extends DB_common

Modified: trunk/lib/pear/DB/msql.php
===================================================================
--- trunk/lib/pear/DB/msql.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/msql.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -23,7 +23,6 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -47,7 +46,7 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  * @since      Class not functional until Release 1.7.0
  */

Modified: trunk/lib/pear/DB/mssql.php
===================================================================
--- trunk/lib/pear/DB/mssql.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/mssql.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -20,7 +20,6 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  * @deprecated since 1.12.0
  */
@@ -50,7 +49,7 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  * @deprecated since 1.12.0
  */

Modified: trunk/lib/pear/DB/mysql.php
===================================================================
--- trunk/lib/pear/DB/mysql.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/mysql.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -20,7 +20,6 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  * @deprecated since 1.12.0
  */
@@ -42,7 +41,7 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  * @deprecated since 1.12.0
  */

Modified: trunk/lib/pear/DB/mysqli.php
===================================================================
--- trunk/lib/pear/DB/mysqli.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/mysqli.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -19,7 +19,6 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -43,7 +42,7 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  * @since      Class functional since Release 1.6.3
  */

Modified: trunk/lib/pear/DB/oci8.php
===================================================================
--- trunk/lib/pear/DB/oci8.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/oci8.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -20,7 +20,6 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -47,7 +46,7 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  */
 class DB_oci8 extends DB_common
@@ -383,7 +382,12 @@
             return $this->raiseError(DB_ERROR_NOT_CAPABLE);
         }
         if ($fetchmode & DB_FETCHMODE_ASSOC) {
-            $moredata = @oci_fetch_array($result,$arr,OCI_ASSOC+OCI_RETURN_NULLS+OCI_RETURN_LOBS);
+            $arr = @oci_fetch_array($result,OCI_ASSOC+OCI_RETURN_NULLS+OCI_RETURN_LOBS);
+            if (is_array($arr)) {
+                $moredata = count($arr);
+            } else {
+                $moredata = false;
+            }
             if ($this->options['portability'] & DB_PORTABILITY_LOWERCASE &&
                 $moredata)
             {
@@ -390,7 +394,12 @@
                 $arr = array_change_key_case($arr, CASE_LOWER);
             }
         } else {
-            $moredata = oci_fetch_array($result,$arr,OCI_RETURN_NULLS+OCI_RETURN_LOBS);
+            $arr = @oci_fetch_array($result,OCI_ASSOC+OCI_RETURN_NULLS+OCI_RETURN_LOBS);
+            if (is_array($arr)) {
+                $moredata = count($arr);
+            } else {
+                $moredata = false;
+            }
         }
         if (!$moredata) {
             return null;

Modified: trunk/lib/pear/DB/odbc.php
===================================================================
--- trunk/lib/pear/DB/odbc.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/odbc.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -20,7 +20,6 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -44,7 +43,7 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  */
 class DB_odbc extends DB_common

Modified: trunk/lib/pear/DB/pgsql.php
===================================================================
--- trunk/lib/pear/DB/pgsql.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/pgsql.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -21,7 +21,6 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -43,7 +42,7 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  */
 class DB_pgsql extends DB_common

Modified: trunk/lib/pear/DB/sqlite.php
===================================================================
--- trunk/lib/pear/DB/sqlite.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/sqlite.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -21,7 +21,6 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -47,7 +46,7 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  */
 class DB_sqlite extends DB_common

Modified: trunk/lib/pear/DB/sqlite3.php
===================================================================
--- trunk/lib/pear/DB/storage.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/storage.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -18,7 +18,6 @@
  * @author     Stig Bakken <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -38,7 +37,7 @@
  * @author     Stig Bakken <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  */
 class DB_storage extends PEAR
@@ -252,7 +251,7 @@
                     if ($i > 0) {
                         $info .= ",";
                     }
-                    $info .= $this->$keyname[$i];
+                    $info .= $this->{$keyname[$i]};
                 }
                 $info .= ")";
             } else {

Modified: trunk/lib/pear/DB/sybase.php
===================================================================
--- trunk/lib/pear/DB/sybase.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/sybase.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -21,7 +21,6 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  * @deprecated since 1.12.0
  */
@@ -47,7 +46,7 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  * @deprecated since 1.12.0
  */

Modified: trunk/lib/pear/DB.php
===================================================================
--- trunk/lib/pear/DB.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -20,7 +20,6 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -440,7 +439,7 @@
  * @author     Daniel Convissor <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  */
 class DB
@@ -591,7 +590,7 @@
      */
     public static function apiVersion()
     {
-        return '1.12.1';
+        return '1.12.2';
     }
 
     // }}}
@@ -962,7 +961,7 @@
  * @author     Stig Bakken <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  */
 class DB_Error extends PEAR_Error
@@ -1023,7 +1022,7 @@
  * @author     Stig Bakken <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  */
 class DB_result
@@ -1488,7 +1487,7 @@
  * @author     Stig Bakken <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  * @see        DB_common::setFetchMode()
  */

Modified: trunk/lib/pear/PEAR.php
===================================================================
--- trunk/lib/pear/PEAR.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/PEAR.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -75,7 +75,7 @@
  * @author     Greg Beaver <[email protected]>
  * @copyright  1997-2006 The PHP Group
  * @license    http://opensource.org/licenses/bsd-license.php New BSD License
- * @version    Release: 1.10.14
+ * @version    Release: 1.10.15
  * @link       http://pear.php.net/package/PEAR
  * @see        PEAR_Error
  * @since      Class available since PHP 4.0.2
@@ -219,7 +219,7 @@
             );
         }
         return call_user_func_array(
-            array(get_class(), '_' . $method),
+            array(__CLASS__, '_' . $method),
             array_merge(array($this), $arguments)
         );
     }
@@ -232,7 +232,7 @@
             );
         }
         return call_user_func_array(
-            array(get_class(), '_' . $method),
+            array(__CLASS__, '_' . $method),
             array_merge(array(null), $arguments)
         );
     }
@@ -845,7 +845,7 @@
  * @author     Gregory Beaver <[email protected]>
  * @copyright  1997-2006 The PHP Group
  * @license    http://opensource.org/licenses/bsd-license.php New BSD License
- * @version    Release: 1.10.14
+ * @version    Release: 1.10.15
  * @link       http://pear.php.net/manual/en/core.pear.pear-error.php
  * @see        PEAR::raiseError(), PEAR::throwError()
  * @since      Class available since PHP 4.0.2

Modified: trunk/locale/it/pgsrc/NoteDiRilascio
===================================================================
--- trunk/locale/it/pgsrc/NoteDiRilascio	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/locale/it/pgsrc/NoteDiRilascio	2024-04-16 08:11:34 UTC (rev 11084)
@@ -1,4 +1,4 @@
-Date: Wed, 13 Mar 2024 10:49:30 +0000
+Date: Tue, 16 Apr 2024 10:09:47 +0000
 Mime-Version: 1.0 (Produced by PhpWiki 1.6.4)
 Content-Type: application/x-phpwiki;
   pagename=NoteDiRilascio;
@@ -8,6 +8,10 @@
 
 <<CreateToc with_toclink||=1 headers||=1,2,3 width=300px position=right>>
 
+== 1.X.X 2024-XX-XX Marc-Etienne Vargenau ==
+
+* Upgrade PEAR to relase 1.10.15, PEAR DB to release 1.12.2
+
 == 1.6.4 2024-03-13 Marc-Etienne Vargenau, Christof Meerwald ==
 
 * Upgrade PEAR to relase 1.10.14, PEAR DB to release 1.12.1

Modified: trunk/pgsrc/ReleaseNotes
===================================================================
--- trunk/pgsrc/ReleaseNotes	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/pgsrc/ReleaseNotes	2024-04-16 08:11:34 UTC (rev 11084)
@@ -1,4 +1,4 @@
-Date: Wed, 13 Mar 2024 10:49:30 +0000
+Date: Tue, 16 Apr 2024 10:09:47 +0000
 Mime-Version: 1.0 (Produced by PhpWiki 1.6.4)
 Content-Type: application/x-phpwiki;
   pagename=ReleaseNotes;
@@ -8,6 +8,10 @@
 
 <<CreateToc with_toclink||=1 headers||=1,2,3 width=300px position=right>>
 
+== 1.X.X 2024-XX-XX Marc-Etienne Vargenau ==
+
+* Upgrade PEAR to relase 1.10.15, PEAR DB to release 1.12.2
+
 == 1.6.4 2024-03-13 Marc-Etienne Vargenau, Christof Meerwald ==
 
 * Upgrade PEAR to relase 1.10.14, PEAR DB to release 1.12.1

This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
--- trunk/lib/pear/DB/sqlite3.php	2024-03-13 18:42:46 UTC (rev 11083)
+++ trunk/lib/pear/DB/sqlite3.php	2024-04-16 08:11:34 UTC (rev 11084)
@@ -21,7 +21,6 @@
  * @author     Armin Graefe <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -28,11 +27,11 @@
 /**
  * Obtain the DB_common class so it can be extended from
  */
-require_once 'DB/common.php';
+require_once 'lib/pear/DB/common.php';
 
 /**
  * The methods PEAR DB uses to interact with PHP's sqlite extension
  * for interacting with SQLite databases
  *
  * These methods overload the ones declared in DB_common.
  *
@@ -48,7 +47,7 @@
  * @author     Armin Graefe <[email protected]>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0 3.0
- * @version    Release: 1.12.1
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  */
 class DB_sqlite3 extends DB_common
@@ -104,7 +103,7 @@
     
     /**
      * The raw database connection created by PHP
-     * @var resource
+     * @var SQLite3 object
      */
     var $connection;
     
@@ -170,7 +169,7 @@
      *
      * Don't call this method directly.  Use DB::connect() instead.
      *
      * PEAR DB's sqlite driver supports the following extra DSN options:
      *   + mode  The permissions for the database file, in four digit
      *            chmod octal format (eg "0600").
      *
@@ -241,8 +240,6 @@
         @ini_set('track_errors', 1);
         $php_errormsg = '';
         
-        //var_dump($this->getOption('readable'));exit();
-        
         if (!$this->connection = @new SQLite3($dsn['database'])) {
             return $this->raiseError(DB_ERROR_NODBSELECTED,
                 null, null, null,
@@ -278,7 +275,7 @@
      *
      * @param string  the SQL query string
      *
      * @return mixed  + a PHP result resrouce for successful SELECT queries
      *                + the DB_OK constant for other successful queries
      *                + a DB_Error object on failure
      */
@@ -298,7 +295,7 @@
             return $this->sqliteRaiseError(null);
         }
         
-        // sqlite_query() seems to allways return a resource
+        // sqlite_query() seems to always return a SQLite3Result object
         // so cant use that. Using $ismanip instead
         if (!$ismanip) {
             $numRows = $this->numRows($result);
@@ -317,7 +314,7 @@
     /**
      * Move the internal sqlite result pointer to the next available result
      *
      * @param resource $result  the valid sqlite result resource
      *
      * @return bool  true if a result is available otherwise return false
      */
@@ -339,10 +336,10 @@
      * DB_result::fetchInto() instead.  It can't be declared "protected"
      * because DB_result is a separate object.
      *
      * @param resource $result    the query result resource
      * @param array    $arr       the referenced array to put the data in
      * @param int      $fetchmode how the resulting array should be indexed
      * @param int      $rownum    the row number to fetch (0 = first row)
      *
      * @return mixed  DB_OK on success, NULL when the end of a result set is
      *                 reached or on failure
@@ -416,7 +413,7 @@
      * DB_result::free() instead.  It can't be declared "protected"
      * because DB_result is a separate object.
      *
-     * @param resource $result  PHP's query result resource
+     * @param SQLite3Result $result  PHP's query SQLite3Result object
      *
      * @return bool  TRUE on success, FALSE if $result is invalid
      *
@@ -425,7 +422,9 @@
     function freeResult(&$result)
     {
         // XXX No native free?
-        if (!is_resource($result)) {
+        if (!is_object($result) || get_class($result) != "SQLite3Result") {
+            // FIXME return false has no effect at DB::free, because PEAR::isError expected
+            // But it returns false in every DBMS, maybe a bug in every DBMS??
             return false;
         }
         $result = null;
@@ -442,7 +441,7 @@
      * DB_result::numCols() instead.  It can't be declared "protected"
      * because DB_result is a separate object.
      *
-     * @param resource $result  PHP's query result resource
+     * @param SQLite3Result $result  PHP's query SQLite3Result object
      *
      * @return int  the number of columns.  A DB_Error object on failure.
      *
@@ -467,7 +466,7 @@
      * DB_result::numRows() instead.  It can't be declared "protected"
      * because DB_result is a separate object.
      *
-     * @param resource $result  PHP's query result resource
+     * @param SQLite3Result $result  PHP's query SQLite3Result object
      *
      * @return int  the number of rows.  A DB_Error object on failure.
      *
@@ -961,4 +960,4 @@
  * End:
  */
 
-?>
\ No newline at end of file
+?>
@@ -28,11 +27,11 @@
 
 /**
- * The methods PEAR DB uses to interact with PHP's sqlite extension
- * for interacting with SQLite databases
+ * The methods PEAR DB uses to interact with PHP's sqlite3 extension
+ * for interacting with SQLite3 databases
  *
  * These methods overload the ones declared in DB_common.
@@ -170,7 +169,7 @@
      * Don't call this method directly.  Use DB::connect() instead.
      *
-     * PEAR DB's sqlite driver supports the following extra DSN options:
+     * PEAR DB's sqlite3 driver supports the following extra DSN options:
      *   + mode  The permissions for the database file, in four digit
      *            chmod octal format (eg "0600").
@@ -278,7 +275,7 @@
      * @param string  the SQL query string
      *
-     * @return mixed  + a PHP result resrouce for successful SELECT queries
+     * @return mixed  + a PHP SQLite3Result object for successful SELECT queries
      *                + the DB_OK constant for other successful queries
      *                + a DB_Error object on failure
@@ -317,7 +314,7 @@
      * Move the internal sqlite result pointer to the next available result
      *
-     * @param resource $result  the valid sqlite result resource
+     * @param SQLite3Result $result  the valid sqlite result SQLite3Result object
      *
      * @return bool  true if a result is available otherwise return false
@@ -339,10 +336,10 @@
      * because DB_result is a separate object.
      *
-     * @param resource $result    the query result resource
-     * @param array    $arr       the referenced array to put the data in
-     * @param int      $fetchmode how the resulting array should be indexed
-     * @param int      $rownum    the row number to fetch (0 = first row)
+     * @param SQLite3Result $result    the query SQLite3Result object
+     * @param array         $arr       the referenced array to put the data in
+     * @param int           $fetchmode how the resulting array should be indexed
+     * @param int           $rownum    the row number to fetch (0 = first row)
      *
      * @return mixed  DB_OK on success, NULL when the end of a result set is

Modified: trunk/lib/pear/DB/storage.php
===================================================================